@@ -5,7 +5,7 @@
 #' @param key the parameter name, e.g. `sessionToken`
 #' @param value the value to set the parameter to
 #' @param json path to the config
-#' 
+#' @return updates configuration and returns silently (`NULL`). 
 #' @examplesIf interactive()
 #' 
 #' mc_config_set("play", key="sessionToken", value="MyTmpSessionToken")
@@ -14,7 +14,7 @@
 mc_config_set <- function(alias,
                           key, 
                           value,
-                          json = "~/.mc/config.json") {
+                          json = file.path(minio_path(), "config.json")) {
   config <- jsonlite::read_json(json)
   
   config[["aliases"]][[alias]][[key]] <- value
